@@ -64,6 +64,7 @@ impl PageInfo {
 }
 
 /// Central store of data.
+#[derive(Default)]
 pub struct Stash {
     /// Write time - number of writes.
     pub time: u64,
@@ -144,17 +145,6 @@ impl Stash {
     }
 }
 
-impl Default for Stash {
-    fn default() -> Self {
-        Self {
-            time: 0,
-            pages: HashMap::new(),
-            readers: BTreeMap::new(),
-            updates: BTreeMap::new(),
-        }
-    }
-}
-
 /// Allows logical database pages to be shared to allow concurrent readers.
 pub struct SharedPagedData {
     pub stash: RwLock<Stash>,
